pub enum FetchDecision {
Allow,
Deny(DenyReason),
}Expand description
Outcome of RemoteResolveConfig::fetch_decision.
Variants
Allow
The reference matches a trusted base and may be fetched.
Deny(DenyReason)
The reference must not be fetched, with the reason.
Implementations
Sourceimpl FetchDecision
impl FetchDecision
Sourcepub fn is_allowed(&self) -> bool
pub fn is_allowed(&self) -> bool
Convenience: whether the decision is FetchDecision::Allow.