undeclared_tables

Function undeclared_tables 

pub fn undeclared_tables<'a>(
    result: &'a ScanResult,
    declared_labels: &[String],
) -> Vec<&'a TableRef>
Returns the tables result found that are not present in declared_labels (compared case-insensitively, like SQLite compares table names), in the order they first appeared in the SQL.