pub fn create_app() -> Router
Create the axum application with all routes and configuration Create the application router with default configuration This is used for testing and can be used for custom server implementations